package jmvanel.popup.actions;

import java.io.IOException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IPath;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IActionDelegate;
import org.eclipse.ui.IObjectActionDelegate;
import org.eclipse.ui.IWorkbenchPart;

public class ActionFolder implements IObjectActionDelegate {
	   private IWorkbenchPart targetPart;
	   ShellCommand projectShellCommand = new ShellCommand();
	   
	public ActionFolder() {
		super();
	}

	/**
	 * @see IObjectActionDelegate#setActivePart(IAction, IWorkbenchPart)
	 */
	public void setActivePart(IAction action, IWorkbenchPart targetPart) {
        this.targetPart = targetPart;
    }

	/** @see IActionDelegate#run(IAction) */
	public void run(IAction action) {
		Shell shell = new Shell();
		ISelection sel = targetPart.getSite().getSelectionProvider()
				.getSelection();
		IResource resource = getResourceFromSelection(sel);

		String actionComment = "New folder Action was executed;";

		if (resource != null) {
			try {
				IProject project = resource.getProject();

				if (project != null) {
					actionComment += ", project name \""
							+ project.getDescription().getName() + "\"\n";
					// path relative to project location
					actionComment += ", project fullPath \""
							+ project.getFullPath() + "\"\n";
					// absolute location on the file system :
					IPath projectfullPath = project.getLocation();
					actionComment += ", project location \"" + projectfullPath
							+ "\"\n";

					if (resource == project)
						// Project
						projectShellCommand.execute(projectfullPath
								.toOSString());
					else if (resource != null)
						// Folder
						projectShellCommand.execute(resource.getLocation()
								+ " " + projectfullPath.toOSString());
				}

			} catch (CoreException e) {
				e.printStackTrace();
				actionComment += ", problem getting project description: " + e;
			} catch (IOException e) {
				e.printStackTrace();
				actionComment += ", problem executing: " + projectShellCommand
						+ ": " + e;
			}
		}
		MessageDialog.openInformation(shell, "Test_popup Plug-in",
				actionComment);
	}

	/**
	 * @see IActionDelegate#selectionChanged(IAction, ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
	}

    /**
     * Get a resource from a selection
     * @param sel
     * @return
     */
	IResource getResourceFromSelection(ISelection sel) {
		IResource resource = null;
		if (sel instanceof IStructuredSelection) {
			IStructuredSelection structuredSelection = (IStructuredSelection) sel;
			Object object = structuredSelection.getFirstElement();
			if ((object != null) && (object instanceof IAdaptable)) {
				resource = (IResource) ((IAdaptable) object).getAdapter(IResource.class);            
			}
		}
		return resource;
	}
}
